@@ -3,8 +3,8 @@ from logging import getLogger
 import numpy as np
 
 from skrobot.coordinates import convert_to_axis_vector
-from skrobot.coordinates.math import cross_product
 from skrobot.coordinates import normalize_vector
+from skrobot.coordinates.math import cross_product
 
 
 logger = getLogger(__name__)
@@ -125,6 +125,19 @@ def calc_dif_with_axis(dif, axis):
     return ret
 
 
+class _MimicJointHook(object):
+
+    def __init__(self, this, other, multiplier, offset):
+        self.this_joint = this
+        self.other_joint = other
+        self.multiplier = multiplier
+        self.offset = offset
+
+    def __call__(self):
+        self.other_joint.joint_angle(
+            self.this_joint.joint_angle() * self.multiplier + self.offset)
+
+
 class Joint(object):
 
     def __init__(self, name=None, child_link=None,
@@ -180,9 +193,11 @@ class Joint(object):
         self._hooks.append(hook)
 
     def register_mimic_joint(self, joint, multiplier, offset):
-        self.register_hook(
-            lambda: joint.joint_angle(
-                self.joint_angle() * multiplier + offset))
+        # NOTE: use _MimicJointHook callable to avoid using lambda function.
+        # Otherwise, lambda function will not be pickled and will not
+        # be deepcopied correctly.
+        mimic_joint_hook = _MimicJointHook(self, joint, multiplier, offset)
+        self.register_hook(mimic_joint_hook)
 
 
 class RotationalJoint(Joint):
@@ -249,13 +264,11 @@ class RotationalJoint(Joint):
             v += self.joint_angle()
         if v > self.max_angle:
             if not relative:
-                logger.warning('{} :joint-angle({}) violate max-angle({})'
-                               .format(self, v, self.max_angle))
+                logger.warning('%s :joint-angle(%s) violate max-angle(%s)', self, v, self.max_angle)
             v = self.max_angle
         elif v < self.min_angle:
             if not relative:
-                logger.warning('{} :joint-angle({}) violate min-angle({})'
-                               .format(self, v, self.min_angle))
+                logger.warning('%s :joint-angle(%s) violate min-angle(%s)', self, v, self.min_angle)
             v = self.min_angle
         diff_angle = v - self._joint_angle
         self._joint_angle = v
@@ -413,13 +426,11 @@ class LinearJoint(Joint):
                 v = v + self._joint_angle
             if v > self.max_angle:
                 if not relative:
-                    logger.warning('{} :joint-angle({}) violate max-angle({})'
-                                   .format(self, v, self.max_angle))
+                    logger.warning('%s :joint-angle(%s) violate max-angle(%s)', self, v, self.max_angle)
                 v = self.max_angle
             elif v < self.min_angle:
                 if not relative:
-                    logger.warning('{} :joint-angle({}) violate min-angle({})'
-                                   .format(self, v, self.min_angle))
+                    logger.warning('%s :joint-angle(%s) violate min-angle(%s)', self, v, self.min_angle)
                 v = self.min_angle
             diff_translation = v - self._joint_angle
             self._joint_angle = v
