@@ -124,7 +124,7 @@ class URDFXMLRootLinkChanger:
         """
         return list(self.links.keys())
 
-    def change_root_link(self, new_root_link, output_path):
+    def change_root_link(self, new_root_link, output_path, robot_name=None):
         """Change the root link and save the modified URDF.
 
         Parameters
@@ -133,6 +133,9 @@ class URDFXMLRootLinkChanger:
             Name of the new root link
         output_path : str
             Path where the modified URDF will be saved
+        robot_name : str, optional
+            New robot name. If None, generates a default name based on
+            the original robot name and new root link.
 
         Raises
         ------
@@ -144,8 +147,13 @@ class URDFXMLRootLinkChanger:
                 "Link '{}' not found in URDF".format(new_root_link))
 
         current_root = self.get_current_root_link()
+
+        # Set robot name if needed
+        if robot_name is not None or new_root_link != current_root:
+            self._set_robot_name(robot_name, new_root_link)
+
         if new_root_link == current_root:
-            # No change needed, just copy the file
+            # No change needed to kinematic tree, just save with new name
             self._save_urdf(output_path)
             return
 
@@ -318,12 +326,18 @@ class URDFXMLRootLinkChanger:
 
         # Invert axis direction
         axis = joint.find('axis')
-        axis_xyz_str = axis.get('xyz', '0 0 0')
-        inv_axis_xyz = [-float(x) for x in axis_xyz_str.split()]
-        axis.set('xyz', ' '.join(map(str, inv_axis_xyz)))
+        if axis is not None:
+            axis_xyz_str = axis.get('xyz', '0 0 0')
+            inv_axis_xyz = [-float(x) for x in axis_xyz_str.split()]
+            axis.set('xyz', ' '.join(map(str, inv_axis_xyz)))
 
         # Adjust visual and collision origin
-        parent_name = joint.find('parent').get('link')
+        parent_elem = joint.find('parent')
+        if parent_elem is None:
+            return
+        parent_name = parent_elem.get('link')
+        if parent_name not in self.links:
+            return
         parent = self.links[parent_name]
         parent_visual = parent.find('visual')
         if parent_visual is not None:
@@ -395,6 +409,8 @@ class URDFXMLRootLinkChanger:
         return xyz.tolist(), rpy.tolist()
 
     def _get_all_children_links(self, parent_link):
+        if parent_link is None:
+            return []
         parent_link_name = parent_link.get('link')
         for link_name, info in self.joint_tree.items():
             if link_name == parent_link_name:
@@ -404,9 +420,17 @@ class URDFXMLRootLinkChanger:
 
     def _get_all_children_joints(self, parent_joint):
         children_joints = []
-        link_name = parent_joint.find('child').get('link')
+        child_elem = parent_joint.find('child')
+        if child_elem is None:
+            return children_joints
+        link_name = child_elem.get('link')
+        if link_name is None:
+            return children_joints
         for joint_name, joint in self.joints.items():
-            parent_link_name = joint.find('parent').get('link')
+            parent_elem = joint.find('parent')
+            if parent_elem is None:
+                continue
+            parent_link_name = parent_elem.get('link')
             if parent_link_name == link_name:
                 children_joints.append(joint)
         return children_joints
@@ -414,12 +438,17 @@ class URDFXMLRootLinkChanger:
     def _get_all_children_joints_of_link(self, link_name):
         children_joints = []
         for joint_name, joint in self.joints.items():
-            parent_link_name = joint.find('parent').get('link')
+            parent_elem = joint.find('parent')
+            if parent_elem is None:
+                continue
+            parent_link_name = parent_elem.get('link')
             if parent_link_name == link_name:
                 children_joints.append(joint)
         return children_joints
 
     def _link_is_included_in_path(self, target_link, path):
+        if target_link is None:
+            return False
         target_link_name = target_link.get('name')
         for elem in path:
             parent_link_name = elem[0]
@@ -429,6 +458,8 @@ class URDFXMLRootLinkChanger:
         return False
 
     def _joint_is_included_in_path(self, target_joint, path):
+        if target_joint is None:
+            return False
         target_joint_name = target_joint.get('name')
         for elem in path:
             joint_name = elem[2]
@@ -453,6 +484,33 @@ class URDFXMLRootLinkChanger:
         # Format the output for better readability
         self._format_xml_file(output_path)
 
+    def get_robot_name(self):
+        """Get the current robot name.
+
+        Returns
+        -------
+        str
+            Current robot name, or 'robot' if not set
+        """
+        return self.root.get('name', 'robot')
+
+    def _set_robot_name(self, robot_name, new_root_link):
+        """Set the robot name.
+
+        Parameters
+        ----------
+        robot_name : str or None
+            New robot name. If None, generates default name.
+        new_root_link : str
+            Name of the new root link (used for default naming)
+        """
+        if robot_name is None:
+            # Generate default name: original_name_root_new_root_link
+            original_name = self.get_robot_name()
+            robot_name = "{}_root_{}".format(original_name, new_root_link)
+
+        self.root.set('name', robot_name)
+
     def _format_xml_file(self, file_path):
         """Format XML file for better readability.
 
@@ -481,7 +539,7 @@ class URDFXMLRootLinkChanger:
             pass
 
 
-def change_urdf_root_link(urdf_path, new_root_link, output_path):
+def change_urdf_root_link(urdf_path, new_root_link, output_path, robot_name=None):
     """Change the root link of a URDF file.
 
     Parameters
@@ -492,6 +550,8 @@ def change_urdf_root_link(urdf_path, new_root_link, output_path):
         Name of the new root link
     output_path : str
         Path where the modified URDF will be saved
+    robot_name : str, optional
+        New robot name. If None, generates a default name.
     """
     changer = URDFXMLRootLinkChanger(urdf_path)
-    changer.change_root_link(new_root_link, output_path)
+    changer.change_root_link(new_root_link, output_path, robot_name=robot_name)
